You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cassandra.apache.org by ms...@apache.org on 2017/08/09 22:41:36 UTC

cassandra git commit: Enable ppc64le runtime as unsupported architecture

Repository: cassandra
Updated Branches:
  refs/heads/trunk c00206297 -> bcdbee5cd


Enable ppc64le runtime as unsupported architecture

patch by Amitkumar Ghatwal and Michael Shuler; reviewed by Jeff Jirsa for CASSANDRA-13615


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/bcdbee5c
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/bcdbee5c
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/bcdbee5c

Branch: refs/heads/trunk
Commit: bcdbee5cdce6e22e6c97c5cab23fb2cf3265aa0d
Parents: c002062
Author: Michael Shuler <mi...@pbandjelly.org>
Authored: Wed Aug 9 15:42:01 2017 -0500
Committer: Michael Shuler <mi...@pbandjelly.org>
Committed: Wed Aug 9 15:50:19 2017 -0500

----------------------------------------------------------------------
 CHANGES.txt                                       |   1 +
 lib/sigar-bin/libsigar-ppc64le-linux.so           | Bin 0 -> 310664 bytes
 .../org/apache/cassandra/utils/Architecture.java  |   7 ++++---
 3 files changed, 5 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/bcdbee5c/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index 53caaba..849848f 100644
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -1,4 +1,5 @@
 4.0
+ * Enable ppc64le runtime as unsupported architecture (CASSANDRA-13615)
  * Improve sstablemetadata output (CASSANDRA-11483)
  * Support for migrating legacy users to roles has been dropped (CASSANDRA-13371)
  * Introduce error metrics for repair (CASSANDRA-13387)

http://git-wip-us.apache.org/repos/asf/cassandra/blob/bcdbee5c/lib/sigar-bin/libsigar-ppc64le-linux.so
----------------------------------------------------------------------
diff --git a/lib/sigar-bin/libsigar-ppc64le-linux.so b/lib/sigar-bin/libsigar-ppc64le-linux.so
new file mode 100644
index 0000000..62303bf
Binary files /dev/null and b/lib/sigar-bin/libsigar-ppc64le-linux.so differ

http://git-wip-us.apache.org/repos/asf/cassandra/blob/bcdbee5c/src/java/org/apache/cassandra/utils/Architecture.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/utils/Architecture.java b/src/java/org/apache/cassandra/utils/Architecture.java
index 2b87de0..3e9f579 100644
--- a/src/java/org/apache/cassandra/utils/Architecture.java
+++ b/src/java/org/apache/cassandra/utils/Architecture.java
@@ -26,15 +26,16 @@ import com.google.common.collect.Sets;
 
 public final class Architecture
 {
     // Note that s390x & aarch64 architecture are not officially supported and adding it here is only done out of convenience
     // for those that want to run C* on this architecture at their own risk (see #11214 & #13326)
     private static final Set<String> UNALIGNED_ARCH = Collections.unmodifiableSet(Sets.newHashSet(
     "i386",
     "x86",
     "amd64",
     "x86_64",
     "s390x",
-    "aarch64"
+    "aarch64",
+    "ppc64le"
     ));
 
     public static final boolean IS_UNALIGNED = UNALIGNED_ARCH.contains(System.getProperty("os.arch"));


---------------------------------------------------------------------
@@ -26,15 +26,16 @@ import com.google.common.collect.Sets;
 public final class Architecture
 {
-    // Note that s390x & aarch64 architecture are not officially supported and adding it here is only done out of convenience
-    // for those that want to run C* on this architecture at their own risk (see #11214 & #13326)
+    // Note that s390x, aarch64, & ppc64le architectures are not officially supported and adding them here is only done out
+    // of convenience for those that want to run C* on these architectures at their own risk (see #11214, #13326, & #13615)
     private static final Set<String> UNALIGNED_ARCH = Collections.unmodifiableSet(Sets.newHashSet(
     "i386",
To unsubscribe, e-mail: commits-unsubscribe@cassandra.apache.org
For additional commands, e-mail: commits-help@cassandra.apache.org